vtproto

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: BSD-3-Clause Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// optional bool mempool = 64101;
	E_Mempool = &file_github_com_runtime_radar_vtprotobuf_vtproto_ext_proto_extTypes[0]
	// optional bool ignore_unknown_fields = 64102;
	E_IgnoreUnknownFields = &file_github_com_runtime_radar_vtprotobuf_vtproto_ext_proto_extTypes[1]
)

Extension fields to descriptorpb.MessageOptions.

var (
	// optional vtproto.Opts options = 64150;
	E_Options = &file_github_com_runtime_radar_vtprotobuf_vtproto_ext_proto_extTypes[2]
)

Extension fields to descriptorpb.FieldOptions.

var File_github_com_runtime_radar_vtprotobuf_vtproto_ext_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Opts

type Opts struct {
	Unique *bool `protobuf:"varint,1,opt,name=unique" json:"unique,omitempty"`
	// contains filtered or unexported fields
}

These options should be used during schema definition, applying them to some of the fields in protobuf

func (*Opts) Descriptor deprecated

func (*Opts) Descriptor() ([]byte, []int)

Deprecated: Use Opts.ProtoReflect.Descriptor instead.

func (*Opts) GetUnique

func (x *Opts) GetUnique() bool

func (*Opts) ProtoMessage

func (*Opts) ProtoMessage()

func (*Opts) ProtoReflect

func (x *Opts) ProtoReflect() protoreflect.Message

func (*Opts) Reset

func (x *Opts) Reset()

func (*Opts) String

func (x *Opts) String() string

Jump to